@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -44,14 +44,14 @@ class RowExporter(AbstractDataExporter):
 
         Parameters
         ----------
-        model : AbstractDataModel instance
+        model : AbstractDataModel
             The data model holding the data.
         indices : list of (row, column) index pairs
             The indices where the data is to be stored.
 
         Returns
         -------
-        data : any
+        data : Any
             The data, of a type that can be serialized by the format.
         """
         rows = sorted({row for row, column in indices})
