@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,10 +15,10 @@ from traits.api import Event, HasTraits
 
 
 from pyface.key_pressed_event import KeyPressedEvent
-from pyface.i_widget import IWidget
+from pyface.i_layout_widget import ILayoutWidget
 
 
-class IPythonShell(IWidget):
+class IPythonShell(ILayoutWidget):
     """ The interface for an interactive Python shell. """
 
     # 'IPythonShell' interface ---------------------------------------------
@@ -38,7 +38,7 @@ class IPythonShell(IWidget):
 
         Returns
         -------
-        interpreter : InteractiveInterpreter instance
+        interpreter : InteractiveInterpreter
             Returns the InteractiveInterpreter instance.
         """
 
@@ -49,7 +49,7 @@ class IPythonShell(IWidget):
         ----------
         name : str
             The python idetifier to bind the value to.
-        value : any
+        value : Any
             The python object to be bound into the interpreter's namespace.
         """
 
@@ -118,7 +118,7 @@ class MPythonShell(HasTraits):
         ----------
         name : str
             The python idetifier to bind the value to.
-        value : any
+        value : Any
             The python object to be bound into the interpreter's namespace.
         """
         self.interpreter().locals[name] = value
