@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,11 +9,7 @@
 # Thanks for using Enthought open source!
 from . import qt_api
 
-if qt_api == "pyqt":
-    from PyQt4.Qt import QKeySequence, QTextCursor
-    from PyQt4.QtGui import *
-
-elif qt_api == "pyqt5":
+if qt_api == "pyqt5":
     from PyQt5.QtGui import *
     from PyQt5.QtWidgets import *
     from PyQt5.QtPrintSupport import *
@@ -30,6 +26,39 @@ elif qt_api == "pyqt5":
     QStyleOptionTabV3 = QStyleOptionTab
     QStyleOptionTabBarBaseV2 = QStyleOptionTabBarBase
 
+elif qt_api == "pyqt6":
+    from PyQt6.QtGui import *
+    from PyQt6.QtWidgets import *
+    from PyQt6.QtPrintSupport import *
+    from PyQt6.QtCore import (
+        QAbstractProxyModel,
+        QItemSelection,
+        QItemSelectionModel,
+        QItemSelectionRange,
+        QSortFilterProxyModel,
+        QStringListModel,
+    )
+
+    QStyleOptionTabV2 = QStyleOptionTab
+    QStyleOptionTabV3 = QStyleOptionTab
+    QStyleOptionTabBarBaseV2 = QStyleOptionTabBarBase
+
+elif qt_api == "pyside6":
+    from PySide6.QtGui import *
+    from PySide6.QtWidgets import *
+    from PySide6.QtPrintSupport import *
+    from PySide6.QtCore import (
+        QAbstractProxyModel,
+        QItemSelection,
+        QItemSelectionModel,
+        QItemSelectionRange,
+        QSortFilterProxyModel,
+    )
+
+    QStyleOptionTabV2 = QStyleOptionTab
+    QStyleOptionTabV3 = QStyleOptionTab
+    QStyleOptionTabBarBaseV2 = QStyleOptionTabBarBase
+
 else:
     from PySide2.QtGui import *
     from PySide2.QtWidgets import *
