@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -38,7 +38,7 @@ def choose_one(parent, message, choices, title="Choose", cancel=True):
 
     Returns
     -------
-    choice : any
+    choice : Any
         The selected object, or None if cancelled.
     """
     dialog = SingleChoiceDialog(
