@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,7 +12,9 @@ from io import StringIO
 import sys
 
 
-from traits.api import Either, Enum, HasStrictTraits, Int, Instance, List, Str
+from traits.api import (
+    Enum, HasStrictTraits, Int, Instance, List, Str, Union,
+)
 
 
 class LayoutItem(HasStrictTraits):
@@ -91,7 +93,7 @@ class LayoutContainer(LayoutItem):
                 )
             else:
                 traits["items"] = list(items)
-        super(LayoutContainer, self).__init__(**traits)
+        super().__init__(**traits)
 
     def iterleaves(self):
         for item in self.items:
@@ -108,7 +110,7 @@ class PaneItem(LayoutItem):
 
     #: The ID of the item. If the item refers to a TaskPane, this is the ID of
     #: that TaskPane.
-    id = Either(Str, Int, default="", pretty_skip=True)
+    id = Union(Str, Int, default_value="", pretty_skip=True)
 
     #: The width of the pane in pixels. If not specified, the pane will be
     #: sized according to its size hint.
@@ -119,7 +121,7 @@ class PaneItem(LayoutItem):
     height = Int(-1)
 
     def __init__(self, id="", **traits):
-        super(PaneItem, self).__init__(**traits)
+        super().__init__(**traits)
         self.id = id
 
     def pargs(self):
@@ -136,7 +138,7 @@ class Tabbed(LayoutContainer):
 
     #: The ID of the TaskPane which is active in layout. If not specified, the
     #: first pane is active.
-    active_tab = Either(Str, Int, default="")
+    active_tab = Union(Str, Int, default_value="")
 
 
 class Splitter(LayoutContainer):
@@ -149,7 +151,7 @@ class Splitter(LayoutContainer):
     #: The sub-items of the splitter, which are PaneItems, Tabbed layouts, and
     #: other Splitters.
     items = List(
-        Either(
+        Union(
             Instance(PaneItem),
             Instance(Tabbed),
             Instance("pyface.tasks.task_layout.Splitter"),
@@ -176,11 +178,11 @@ class DockLayout(LayoutItem):
     """ The layout for a main window's dock area.
     """
 
-    #: The layouts for the task's dock panes.
-    left = Either(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
-    right = Either(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
-    top = Either(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
-    bottom = Either(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
+    # The layouts for the task's dock panes.
+    left = Union(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
+    right = Union(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
+    top = Union(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
+    bottom = Union(Instance(PaneItem), Instance(Tabbed), Instance(Splitter))
 
     #: Assignments of dock areas to the window's corners. By default, the top
     #: and bottom dock areas extend into both of the top and both of the
