@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -36,7 +36,7 @@ class TraitsEditor(Editor):
         """
         if self.model:
             return {"object": self.model, "editor": self}
-        return super(TraitsEditor, self).trait_context()
+        return super().trait_context()
 
     # ------------------------------------------------------------------------
     # 'IEditor' interface.
