@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -18,7 +18,7 @@ from ..image_resource import ImageResource
 from ..toolkit import toolkit_object
 from ..window import Window
 
-is_qt = toolkit_object.toolkit == "qt4"
+is_qt = toolkit_object.toolkit.startswith("qt")
 if is_qt:
     from pyface.qt import qt_api
 
@@ -50,7 +50,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
     def test_create(self):
         # test that creation and destruction works as expected
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -63,7 +63,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that size works as expected
         self.dialog.size = (100, 100)
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -71,7 +71,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that position works as expected
         self.dialog.position = (100, 100)
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -79,10 +79,9 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works as expected with a parent
         with self.event_loop():
             parent = Window()
-            self.dialog.parent = parent.control
-            parent._create()
+            parent.create(parent.control)
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
         with self.event_loop():
@@ -92,7 +91,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works as expected with ok_label
         self.dialog.yes_label = "Sure"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -100,7 +99,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works as expected with ok_label
         self.dialog.no_label = "No Way"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -108,7 +107,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works as expected with ok_label
         self.dialog.default = YES
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -116,7 +115,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works with cancel button
         self.dialog.cancel = True
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -125,7 +124,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.cancel = True
         self.dialog.cancel_label = "Back"
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -134,7 +133,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.cancel = True
         self.dialog.default = CANCEL
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -142,7 +141,7 @@ class TestConfirmationDialog(unittest.TestCase, GuiTestAssistant):
         # test that creation and destruction works with a non-standard image
         self.dialog.image = ImageResource("core")
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -291,6 +290,24 @@ class TestConfirm(unittest.TestCase, GuiTestAssistant):
     def tearDown(self):
         GuiTestAssistant.tearDown(self)
 
+    @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
+    def test_extras(self):
+        # test that label and extra text arguments work
+        tester = ModalDialogTester(
+            lambda: confirm(
+                None,
+                "message",
+                default=NO,
+                no_label="Reject",
+                yes_label="Confirm",
+                informative="informative",
+                detail="detail",
+            )
+        )
+        tester.open_and_run(when_opened=lambda x: x.close(accept=True))
+
+        self.assertEqual(tester.result, OK)
+
     @unittest.skipIf(no_modal_dialog_tester, "ModalDialogTester unavailable")
     def test_reject(self):
         # test that cancel works as expected
