@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -29,11 +29,11 @@ class TestPythonEditor(unittest.TestCase, GuiTestAssistant):
     def setUp(self):
         GuiTestAssistant.setUp(self)
         self.window = Window()
-        self.window._create()
+        self.window.create()
 
     def tearDown(self):
         if self.widget.control is not None:
-            with self.delete_widget(self.widget.control):
+            with self.delete_widget(self.window.control):
                 self.widget.destroy()
         if self.window.control is not None:
             with self.delete_widget(self.window.control):
@@ -43,29 +43,41 @@ class TestPythonEditor(unittest.TestCase, GuiTestAssistant):
         GuiTestAssistant.tearDown(self)
 
     def test_lifecycle(self):
-        # test that destroy works
+        # test that create/destroy works
+        self.widget = PythonEditor(self.window.control)
+
+        self.assertIsNone(self.widget.control)
+
         with self.event_loop():
-            with self.assertWarns(PendingDeprecationWarning):
-                self.widget = PythonEditor(self.window.control)
+            self.widget.create(parent=self.window.control)
+
+        self.assertIsNotNone(self.widget.control)
+
+        with self.event_loop():
+            self.widget.destroy()
+
+    def test_one_stage_create(self):
+        # test that automatic creation works
+        with self.event_loop():
+            with self.assertWarns(DeprecationWarning):
+                self.widget = PythonEditor(self.window.control, create=True)
 
         self.assertIsNotNone(self.widget.control)
-        self.assertFalse(self.widget.dirty)
 
         with self.event_loop():
             self.widget.destroy()
 
     def test_two_stage_create(self):
-        # test that create and destroy work
-        self.widget = PythonEditor(create=False)
+        # test that create=False works
+        with self.assertWarns(DeprecationWarning):
+            self.widget = PythonEditor(self.window.control, create=False)
 
         self.assertIsNone(self.widget.control)
 
         with self.event_loop():
-            self.widget.parent = self.window.control
-            self.widget.create()
+            self.widget.create(parent=self.window.control)
 
         self.assertIsNotNone(self.widget.control)
-        self.assertFalse(self.widget.dirty)
 
         with self.event_loop():
             self.widget.destroy()
@@ -76,7 +88,6 @@ class TestPythonEditor(unittest.TestCase, GuiTestAssistant):
             self.widget = PythonEditor(
                 parent=self.window.control,
                 show_line_numbers=False,
-                create=False,
             )
             self.widget.create()
 
@@ -94,7 +105,6 @@ class TestPythonEditor(unittest.TestCase, GuiTestAssistant):
         with self.event_loop():
             self.widget = PythonEditor(
                 parent=self.window.control,
-                create=False,
             )
             self.widget.create()
 
@@ -112,7 +122,6 @@ class TestPythonEditor(unittest.TestCase, GuiTestAssistant):
             self.widget = PythonEditor(
                 parent=self.window.control,
                 path=PYTHON_SCRIPT,
-                create=False,
             )
             self.widget.create()
 
