@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,7 +11,6 @@
 
 import unittest
 
-from ..gui import GUI
 from ..image_resource import ImageResource
 from ..splash_screen import SplashScreen
 from ..toolkit import toolkit_object
@@ -53,7 +52,7 @@ class TestWindow(unittest.TestCase, GuiTestAssistant):
     def test_show(self):
         # test that show works as expected
         with self.event_loop():
-            self.window._create()
+            self.window.create()
         with self.event_loop():
             self.window.show(True)
         with self.event_loop():
