@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -24,12 +24,16 @@ from traits.api import (
     Enum,
     Range,
     TraitError,
+    TraitFactory,
     TraitType,
 )
 from traits.trait_base import get_resource_path
 
 from pyface.color import Color
+from pyface.font import Font
+from pyface.i_image import IImage
 from pyface.util.color_parser import ColorParseError
+from pyface.util.font_parser import simple_parser, FontParseError
 
 
 logger = logging.getLogger(__name__)
@@ -38,7 +42,10 @@ logger = logging.getLogger(__name__)
 #  Images
 # -------------------------------------------------------------------------------
 
+# cache of lookups from string to ImageResource instance
 image_resource_cache = {}
+
+# cache of conversions of ImageResource instances to toolkit bitmaps
 image_bitmap_cache = {}
 
 
@@ -75,28 +82,32 @@ def convert_image(value, level=3):
     return result
 
 
-def convert_bitmap(image_resource):
+def convert_bitmap(image):
     """ Converts an ImageResource to a bitmap using a cache.
     """
-    bitmap = image_bitmap_cache.get(image_resource)
-    if (bitmap is None) and (image_resource is not None):
-        image_bitmap_cache[
-            image_resource
-        ] = bitmap = image_resource.create_bitmap()
+    from pyface.i_image_resource import IImageResource
+    if not isinstance(image, IImageResource):
+        # don't try to cache non-ImageResource IImages as they may be
+        # dynamically changing
+        return image.create_bitmap()
+
+    bitmap = image_bitmap_cache.get(image)
+    if (bitmap is None) and (image is not None):
+        image_bitmap_cache[image] = bitmap = image.create_bitmap()
 
     return bitmap
 
 
 class Image(TraitType):
-    """ Defines a trait whose value must be a ImageResource or a string
-        that can be converted to one.
+    """ Defines a trait whose value must be a IImage or a string
+        that can be converted to an IImageResource.
     """
 
-    # Define the default value for the trait:
+    #: Define the default value for the trait.
     default_value = None
 
-    # A description of the type of value this trait accepts:
-    info_text = "an ImageResource or string that can be used to define one"
+    #: A description of the type of value this trait accepts.
+    info_text = "an IImage or string that can be used to define an ImageResource"  # noqa: E501
 
     def __init__(self, value=None, **metadata):
         """ Creates an Image trait.
@@ -104,21 +115,19 @@ class Image(TraitType):
         Parameters
         ----------
         value : string or ImageResource
-            The default value for the Image, either an ImageResource object,
+            The default value for the Image, either an IImage object,
             or a string from which an ImageResource object can be derived.
         """
-        super(Image, self).__init__(convert_image(value), **metadata)
+        super().__init__(convert_image(value), **metadata)
 
     def validate(self, object, name, value):
         """ Validates that a specified value is valid for this trait.
         """
-        from pyface.i_image_resource import IImageResource
-
         if value is None:
             return None
 
         new_value = convert_image(value, 4)
-        if isinstance(new_value, IImageResource):
+        if isinstance(new_value, IImage):
             return new_value
 
         self.error(object, name, value)
@@ -137,10 +146,10 @@ class Image(TraitType):
 
 
 class PyfaceColor(TraitType):
-    """ A Trait which casts strings and tuples to a PyfaceColor value.
+    """ A Trait which casts strings and tuples to a Pyface Color value.
     """
 
-    #: The default value should be a tuple (factory, args, kwargs)
+    #: The default value should be a tuple (factory, args, kwargs).
     default_value_type = DefaultValue.callable_and_args
 
     def __init__(self, value=None, **metadata):
@@ -152,6 +161,11 @@ class PyfaceColor(TraitType):
         super().__init__(default_value, **metadata)
 
     def validate(self, object, name, value):
+        """Validate the trait
+
+        This accepts, Color values, parseable strings and RGB(A) sequences
+        (including numpy arrays).
+        """
         if isinstance(value, Color):
             return value
         if isinstance(value, str):
@@ -173,27 +187,89 @@ class PyfaceColor(TraitType):
         self.error(object, name, value)
 
     def info(self):
+        """Describe the trait"""
         return (
             "a Pyface Color, a #-hexadecimal rgb or rgba string,  a standard "
             "color name, or a sequence of RGBA or RGB values between 0 and 1"
         )
 
 
+# -------------------------------------------------------------------------------
+#  Font
+# -------------------------------------------------------------------------------
+
+
+class PyfaceFont(TraitType):
+    """ A Trait which casts strings to a Pyface Font value.
+    """
+
+    #: The default value should be a tuple (factory, args, kwargs)
+    default_value_type = DefaultValue.callable_and_args
+
+    #: The parser to use when converting text to keyword args.  This should
+    #: accept a string and return a dictionary of Font class trait values (ie.
+    #: "family", "size", "weight", etc.).
+    parser = None
+
+    def __init__(self, value=None, *, parser=simple_parser, **metadata):
+        self.parser = parser
+        if value is not None:
+            try:
+                font = self.validate(None, None, value)
+            except TraitError:
+                raise ValueError(
+                    "expected " + self.info()
+                    + f", but got {value!r}"
+                )
+            default_value = (
+                Font,
+                (),
+                font.trait_get(transient=lambda x: not x),
+            )
+        else:
+            default_value = (Font, (), {})
+        super().__init__(default_value, **metadata)
+
+    def validate(self, object, name, value):
+        """Validate the trait
+
+        This accepts, Font values and parseable strings.
+        """
+        if isinstance(value, Font):
+            return value
+        if isinstance(value, str):
+            try:
+                return Font(**self.parser(value))
+            except FontParseError:
+                self.error(object, name, value)
+
+        self.error(object, name, value)
+
+    def info(self):
+        """Describe the trait"""
+        return (
+            "a Pyface Font, or a string describing a Pyface Font"
+        )
+
+
 # -------------------------------------------------------------------------------
 #  Borders, Margins and Layout
 # -------------------------------------------------------------------------------
 
 
 class BaseMB(ABCHasStrictTraits):
-    def __init__(self, *args, **traits):
-        """ Map posiitonal arguments to traits.
+    """ Base class for Margins and Borders
 
-        If one value is provided it is taken as the value for all sides.
-        If two values are provided, then the first argument is used for
-        left and right, while the second is used for top and bottom.
-        If 4 values are provided, then the arguments are mapped to
-        left, right, top, and bottom, respectively.
-        """
+    The constructor of this class maps posiitonal arguments to traits.
+
+    - If one value is provided it is taken as the value for all sides.
+    - If two values are provided, then the first argument is used for
+      left and right, while the second is used for top and bottom.
+    - If 4 values are provided, then the arguments are mapped to
+      left, right, top, and bottom, respectively.
+    """
+
+    def __init__(self, *args, **traits):
         n = len(args)
         if n > 0:
             if n == 1:
@@ -211,36 +287,38 @@ class BaseMB(ABCHasStrictTraits):
                 {"left": left, "right": right, "top": top, "bottom": bottom}
             )
 
-        super(BaseMB, self).__init__(**traits)
+        super().__init__(**traits)
 
 
 class Margin(BaseMB):
+    """A HasTraits class that holds margin sizes."""
 
-    # The amount of padding/margin at the top:
+    #: The amount of padding/margin at the top.
     top = Range(-32, 32, 0)
 
-    # The amount of padding/margin at the bottom:
+    #: The amount of padding/margin at the bottom.
     bottom = Range(-32, 32, 0)
 
-    # The amount of padding/margin on the left:
+    #: The amount of padding/margin on the left.
     left = Range(-32, 32, 0)
 
-    # The amount of padding/margin on the right:
+    #: The amount of padding/margin on the right.
     right = Range(-32, 32, 0)
 
 
 class Border(BaseMB):
+    """A HasTraits class that holds border thicknesses."""
 
-    # The amount of border at the top:
+    #: The amount of border at the top.
     top = Range(0, 32, 0)
 
-    # The amount of border at the bottom:
+    #: The amount of border at the bottom.
     bottom = Range(0, 32, 0)
 
-    # The amount of border on the left:
+    #: The amount of border on the left.
     left = Range(0, 32, 0)
 
-    # The amount of border on the right:
+    #: The amount of border on the right.
     right = Range(0, 32, 0)
 
 
@@ -249,13 +327,13 @@ class HasMargin(TraitType):
         tuple value that can be converted to one.
     """
 
-    # The desired value class:
+    #: The desired value class.
     klass = Margin
 
-    # Define the default value for the trait:
+    #: Define the default value for the trait.
     default_value = Margin(0)
 
-    # A description of the type of value this trait accepts:
+    #: A description of the type of value this trait accepts.
     info_text = (
         "a Margin instance, or an integer in the range from -32 to 32 "
         "or a tuple with 1, 2 or 4 integers in that range that can be "
@@ -296,7 +374,7 @@ class HasMargin(TraitType):
                 dv = self.klass(*dv)
 
             if not isinstance(dv, self.klass):
-                return super(HasMargin, self).get_default_value()
+                return super().get_default_value()
 
             self.default_value_type = dvt = DefaultValue.callable_and_args
             dv = (self.klass, (), dv.trait_get())
@@ -309,13 +387,13 @@ class HasBorder(HasMargin):
         or tuple value that can be converted to one.
     """
 
-    # The desired value class:
+    #: The desired value class.
     klass = Border
 
-    # Define the default value for the trait:
+    #: Define the default value for the trait.
     default_value = Border(0)
 
-    # A description of the type of value this trait accepts:
+    #: A description of the type of value this trait accepts.
     info_text = (
         "a Border instance, or an integer in the range from 0 to 32 "
         "or a tuple with 1, 2 or 4 integers in that range that can be "
@@ -328,3 +406,44 @@ Position = Enum("left", "right", "above", "below")
 
 #: The alignment of text within a control.
 Alignment = Enum("default", "left", "center", "right")
+
+#: Whether the orientation of a widget's contents is horizontal or vertical.
+Orientation = Enum("vertical", "horizontal")
+
+
+# -------------------------------------------------------------------------------
+#  Legacy TraitsUI Color and Font Traits
+# -------------------------------------------------------------------------------
+
+def TraitsUIColor(*args, **metadata):
+    """ Returns a trait whose value must be a GUI toolkit-specific color.
+
+    This is copied from the deprecated trait that is in traits.api.  It adds
+    a deferred dependency on TraitsUI.
+
+    This trait will be replaced by native Pyface color traits in Pyface 8.0.
+    New code should not use this trait.
+    """
+    from traitsui.toolkit_traits import ColorTrait
+
+    return ColorTrait(*args, **metadata)
+
+
+TraitsUIColor = TraitFactory(TraitsUIColor)
+
+
+def TraitsUIFont(*args, **metadata):
+    """ Returns a trait whose value must be a GUI toolkit-specific font.
+
+    This is copied from the deprecated trait that is in traits.api.  It adds
+    a deferred dependency on TraitsUI.
+
+    This trait will be replaced by native Pyface font traits in Pyface 8.0.
+    New code should not use this trait.
+    """
+    from traitsui.toolkit_traits import FontTrait
+
+    return FontTrait(*args, **metadata)
+
+
+TraitsUIFont = TraitFactory(TraitsUIFont)
