@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -35,7 +35,7 @@ class TreeContentProvider(ContentProvider):
 
         """
 
-        return get_children(element)
+        return self.get_children(element)
 
     # ------------------------------------------------------------------------
     # 'TreeContentProvider' interface.
