@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -85,7 +85,7 @@ class MWizard(HasTraits):
         """ Creates the window contents. """
 
         # This creates the dialog and button areas.
-        super(MWizard, self)._create_contents(parent)
+        super()._create_contents(parent)
 
         # Wire up the controller.
         self._initialize_controller(self.controller)
